==> zio-aws-schemas_2.13-5.17.115.1-sources.jar: zio/aws/schemas/model/DeleteRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteRegistryRequest(registryName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest = {
    import DeleteRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
      .builder()
      .registryName(__string.unwrap(registryName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly =
    zio.aws.schemas.model.DeleteRegistryRequest.wrap(buildAwsValue())
}
object DeleteRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DeleteRegistryRequest =
      zio.aws.schemas.model.DeleteRegistryRequest(registryName)
    def registryName: __string
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ) extends zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly {
    override val registryName: __string =
      zio.aws.schemas.model.primitives.__string(impl.registryName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ): zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.295.10-sources.jar: zio/aws/schemas/model/DeleteRegistryRequest.scala <==
package zio.aws.schemas.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.schemas.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DeleteRegistryRequest(registryName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest = {
    import DeleteRegistryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
      .builder()
      .registryName(registryName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly =
    zio.aws.schemas.model.DeleteRegistryRequest.wrap(buildAwsValue())
}
object DeleteRegistryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.DeleteRegistryRequest =
      zio.aws.schemas.model.DeleteRegistryRequest(registryName)
    def registryName: __string
    def getRegistryName: ZIO[Any, Nothing, __string] = ZIO.succeed(registryName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ) extends zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly {
    override val registryName: __string = impl.registryName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.DeleteRegistryRequest
  ): zio.aws.schemas.model.DeleteRegistryRequest.ReadOnly = new Wrapper(impl)
}
